botrun.ai backend

### .env 檔案要先建立在botrun_back根目錄，填上正確的內容
```
GCP_SERVICE_ACCOUNT=
GCP_PROJECT_ID=
OPENAI_API_KEY=
BOTRUN_JWT_SECRET_KEY=
GITHUB_ACCESS_TOKEN=
```

### 安裝方法
要建立 .env 檔案把相關的 key 都放進去
chmod +x sh/install.sh
sh/install.sh

### local執行方法
chmod +x sh/go.sh
sh/go.sh
